/*
 * COPYRIGHT 2015 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 */

#import <Foundation/Foundation.h>
#import "YSAdManagement.h"
#import "YSUIProperties.h"

/** The YSNonLinearCreative protocol provides an interface to an advert's non-linear creative object - if VAST is associated with the advert, and whose details are passed as a payload during analytic callbacks. There may be zero or more non-linear creatives associated with an advert.
 
 */
@protocol YSNonLinearCreative <NSObject>

/** Returns the nonlinear creative's identifier.
 
 @param none
 @return The identifier.
 @since from 1.0
 */
- (NSString* _Nonnull) nonlinearIdentifier;

/** Returns the nonlinear creative's sequence number.
 
 @param none
 @return The sequence identifier.
 @since from 1.0
 */
- (NSString* _Nullable) nonlinearSequenceIdentifier;

/** Returns the nonlinear creative's Ad identifier.
 
 @param none
 @return The Ad identifier.
 @since from 1.0
 */
- (NSString* _Nullable) nonlinearAdIdentifier;

/** Returns the nonlinear creative's clickthrough URL.
 
 @param none
 @return The clickthrough URL.
 @since from 1.0
 */
- (NSURL* _Nonnull) nonlinearClickthroughURL;

/** Returns the nonlinear creative's source URL.
 
 @param none
 @return The source URL.
 @since from 1.0
 */
- (NSURL* _Nonnull) creativeSource;

/** Returns the nonlinear creative's pre-loaded resource, if pre-loading of VAST resources are enabled
 for this type. Pre-loading policy is defined by the PlayerPolicy component (YPPolicyHandling implememtation)
 
 If the nonlinear is an htmlResource, the data is returned as an `NSString`.<br/>
 If the nonlinear is a staticResource or iFrameResource, the data is returned as an `NSData`.
 
 @param none
 @return The pre-loaded resource (as an `NSString` or `NSData`) or nil.
 @since from 1.0
 */
- (id _Nonnull) creativeElement;

/** Returns the nonlinear creative's user interface properties.
 
 @param none
 @return The user interface properties.
 @since from 1.0
 */
- (id<YSUIProperties> _Nonnull) userInterfaceProperties;

/** Returns the minimum duration that the nonlinear creative should be displayed for.
 
 @param none
 @return The minimum duration.
 @since from 1.0
 */
- (NSTimeInterval) minimumSuggestedDuration;

/** Returns the MIME type of the nonlinear creative's source.
 
 @param none
 @return The MIME type.
 @since from 1.0
 */
- (YSECreativeMIMEType) creativeMIMEType;

/** Returns any adParameters associated with this nonlinear creative.<br/>
 Note that the string is always XML encoded.
 
 @param none
 @return adParameters associated with this nonlinear creative.
 @since from 1.2
 */
- (NSString* _Nullable) nonlinearAdParameters;

@end
